@@ -24,24 +24,37 @@
 */
 var NAVTREE =
 [
-  [ "My Project", "index.html", [
-    [ "Reference Manual (Version 2.0.17)", "index.html", [
+  [ "JasPer", "index.html", [
+    [ "Reference Manual (Version 2.0.24)", "index.html", [
       [ "Introduction", "index.html#intro", null ],
+      [ "News", "index.html#news", null ],
       [ "License", "index.html#license", null ],
       [ "Reporting Bugs", "index.html#bugs", null ]
     ] ],
     [ "Getting Started", "getting_started.html", "getting_started" ],
     [ "Frequently Asked Questions (FAQ)", "faq.html", null ],
     [ "Known Bugs", "known_bugs.html", null ],
+    [ "Todo List", "todo.html", null ],
+    [ "Modules", "modules.html", "modules" ],
+    [ "Classes", "annotated.html", [
+      [ "Class List", "annotated.html", "annotated_dup" ]
+    ] ],
     [ "Files", "files.html", [
-      [ "File List", "files.html", "files_dup" ]
+      [ "File List", "files.html", "files_dup" ],
+      [ "File Members", "globals.html", [
+        [ "All", "globals.html", null ],
+        [ "Functions", "globals_func.html", null ],
+        [ "Typedefs", "globals_type.html", null ],
+        [ "Macros", "globals_defs.html", null ]
+      ] ]
     ] ]
   ] ]
 ];
 
 var NAVTREEINDEX =
 [
-"bmp__cod_8h_source.html"
+"annotated.html",
+"jpc__enc_8h_source.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
